@@ -9,7 +9,7 @@ package WWW::Salesforce;
     use WWW::Salesforce::Deserializer;
     use vars qw( $VERSION );
     
-    $VERSION = '0.02';
+    $VERSION = '0.04';
     
     our $errstr = '';
     
@@ -599,7 +599,7 @@ __END__
 =pod
 =head1 NAME
 
-WWW::Salesforce v0.02 - this class provides a simple abstraction layer between SOAP::Lite and Salesforce.com.
+WWW::Salesforce v0.04 - this class provides a simple abstraction layer between SOAP::Lite and Salesforce.com.
 
 =head1 SYNOPSIS
 
@@ -848,20 +848,6 @@ Please visit Salesforce.com's user/developer forums online for assistance with
 this module. You are free to contact the author directly if you are unable to
 resolve your issue online.
 
-=head1 CHANGE HISTORY
-
-=head2 2006-01-18  v0.02
-    -added the deserializer.
-    -added describeLayout() API call
-    -removed code found in every API call and made a single function for it. updates in one place now instead of many
-    -added another test case to the install
-    -fixed some documentation.
-    -using API version 6 instead of version 4 from Salesforce
-    
-=head2 2006-01-17  v0.01
-    -re-wrote the module to be more easily subclassed
-    -released to CPAN
-
 =head1 AUTHORS
 
 Chase Whitener <cwhitener at gmail dot com>
@@ -874,4 +860,4 @@ Byrne Reese maintains SOAP::Lite and wrote the original Salesforce module.  The
 =head1 COPYRIGHT
 
 Copyright 2003-2004 Byrne Reese. All rights reserved.
-=cut
\ No newline at end of file
+=cut
